==> zio-aws-codepipeline_2.13-5.20.22.2-sources.jar: zio/aws/codepipeline/model/GetActionTypeRequest.scala <==
package zio.aws.codepipeline.model
import zio.aws.codepipeline.model.primitives.{
  Version,
  ActionProvider,
  ActionTypeOwner
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class GetActionTypeRequest(
    category: zio.aws.codepipeline.model.ActionCategory,
    owner: ActionTypeOwner,
    provider: ActionProvider,
    version: Version
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codepipeline.model.GetActionTypeRequest = {
    import GetActionTypeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codepipeline.model.GetActionTypeRequest
      .builder()
      .category(category.unwrap)
      .owner(ActionTypeOwner.unwrap(owner): java.lang.String)
      .provider(ActionProvider.unwrap(provider): java.lang.String)
      .version(Version.unwrap(version): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.codepipeline.model.GetActionTypeRequest.ReadOnly =
    zio.aws.codepipeline.model.GetActionTypeRequest.wrap(buildAwsValue())
}
object GetActionTypeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codepipeline.model.GetActionTypeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codepipeline.model.GetActionTypeRequest =
      zio.aws.codepipeline.model.GetActionTypeRequest(
        category,
        owner,
        provider,
        version
      )
    def category: zio.aws.codepipeline.model.ActionCategory
    def owner: ActionTypeOwner
    def provider: ActionProvider
    def version: Version
    def getCategory
        : ZIO[Any, Nothing, zio.aws.codepipeline.model.ActionCategory] =
      ZIO.succeed(category)
    def getOwner: ZIO[Any, Nothing, ActionTypeOwner] = ZIO.succeed(owner)
    def getProvider: ZIO[Any, Nothing, ActionProvider] = ZIO.succeed(provider)
    def getVersion: ZIO[Any, Nothing, Version] = ZIO.succeed(version)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codepipeline.model.GetActionTypeRequest
  ) extends zio.aws.codepipeline.model.GetActionTypeRequest.ReadOnly {
    override val category: zio.aws.codepipeline.model.ActionCategory =
      zio.aws.codepipeline.model.ActionCategory.wrap(impl.category())
    override val owner: ActionTypeOwner =
      zio.aws.codepipeline.model.primitives.ActionTypeOwner(impl.owner())
    override val provider: ActionProvider =
      zio.aws.codepipeline.model.primitives.ActionProvider(impl.provider())
    override val version: Version =
      zio.aws.codepipeline.model.primitives.Version(impl.version())
  }
  def wrap(
      impl: software.amazon.awssdk.services.codepipeline.model.GetActionTypeRequest
  ): zio.aws.codepipeline.model.GetActionTypeRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-codepipeline_3-5.19.7.1-sources.jar: zio/aws/codepipeline/model/GetActionTypeRequest.scala <==
package zio.aws.codepipeline.model
import zio.aws.codepipeline.model.primitives.{
  Version,
  ActionProvider,
  ActionTypeOwner
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class GetActionTypeRequest(
    category: zio.aws.codepipeline.model.ActionCategory,
    owner: ActionTypeOwner,
    provider: ActionProvider,
    version: Version
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codepipeline.model.GetActionTypeRequest = {
    import GetActionTypeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codepipeline.model.GetActionTypeRequest
      .builder()
      .category(category.unwrap)
      .owner(ActionTypeOwner.unwrap(owner): java.lang.String)
      .provider(ActionProvider.unwrap(provider): java.lang.String)
      .version(Version.unwrap(version): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.codepipeline.model.GetActionTypeRequest.ReadOnly =
    zio.aws.codepipeline.model.GetActionTypeRequest.wrap(buildAwsValue())
}
object GetActionTypeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codepipeline.model.GetActionTypeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codepipeline.model.GetActionTypeRequest =
      zio.aws.codepipeline.model.GetActionTypeRequest(
        category,
        owner,
        provider,
        version
      )
    def category: zio.aws.codepipeline.model.ActionCategory
    def owner: ActionTypeOwner
    def provider: ActionProvider
    def version: Version
    def getCategory
        : ZIO[Any, Nothing, zio.aws.codepipeline.model.ActionCategory] =
      ZIO.succeed(category)
    def getOwner: ZIO[Any, Nothing, ActionTypeOwner] = ZIO.succeed(owner)
    def getProvider: ZIO[Any, Nothing, ActionProvider] = ZIO.succeed(provider)
    def getVersion: ZIO[Any, Nothing, Version] = ZIO.succeed(version)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codepipeline.model.GetActionTypeRequest
  ) extends zio.aws.codepipeline.model.GetActionTypeRequest.ReadOnly {
    override val category: zio.aws.codepipeline.model.ActionCategory =
      zio.aws.codepipeline.model.ActionCategory.wrap(impl.category())
    override val owner: ActionTypeOwner =
      zio.aws.codepipeline.model.primitives.ActionTypeOwner(impl.owner())
    override val provider: ActionProvider =
      zio.aws.codepipeline.model.primitives.ActionProvider(impl.provider())
    override val version: Version =
      zio.aws.codepipeline.model.primitives.Version(impl.version())
  }
  def wrap(
      impl: software.amazon.awssdk.services.codepipeline.model.GetActionTypeRequest
  ): zio.aws.codepipeline.model.GetActionTypeRequest.ReadOnly = new Wrapper(
    impl
  )
}
